zonar_ds_logger
======

Overview
------
A logger class that initializes a logger and logs in json when specified. 
It also redirects flask logs so it doesn’t always show up as ERROR

Usage
------
```python
from zonar_ds_logger.logger import logger

logger.initialize("evan-test", "info", False)
log = logger.get_logger()

log.debug("debug")
log.info("info")
log.warning("warning")
log.error("error")
```

Arguments
------
Parameters that can be passed into logger.initialize are as follows:

- name (str): Name of the logger
- log_level (str): Lowest log level to log. Default is "debug". Options are "debug", "info", "warning", "error"
- json_logging (bool): Whether to log in json or not. Options that evaluate to true are ("true", "t", "1", "y", "yes")
                     Default converts value in JSON_LOGGING env var to bool if set else True
